
.. _algorithms/vertexcover:

Vertex Cover
************

Algorithms
----------

A vertex cover is a set of vertices which covers (touches) all edges of the graph.
Finding a minimum vertex cover is an NP-Complete problem. This module contains various
algorithms for the computation of "good" vertex covers. For more information, 
see `Vertex Cover <https://mathworld.wolfram.com/VertexCover.html>`_.

.. automodule:: jgrapht.algorithms.vertexcover
   :members:

